@@ -1,8 +1,9 @@
 import logging
 
 from kouyierr import index
-from kouyierr.commands import invoice
 from kouyierr.commands import documentation
+from kouyierr.commands import invoice
+from kouyierr.commands import ghproject
 
 
 def main() -> None:
@@ -10,5 +11,6 @@ def main() -> None:
     logging.getLogger(__package__).setLevel(logging.INFO)
     invoice.register()
     documentation.register()
+    ghproject.register()
     index.register()
     index.index()
